# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='service.proto',
  package='eloope',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rservice.proto\x12\x06\x65loope\"]\n\x11SendStatusRequest\x12\r\n\x05tasks\x18\x01 \x01(\x0c\x12\x17\n\x0f\x63ompleted_tasks\x18\x02 \x01(\x0c\x12\x12\n\nfree_count\x18\x03 \x01(\x05\x12\x0c\n\x04logs\x18\x04 \x01(\x0c\"4\n\x12SendStatusResponse\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\r\n\x05tasks\x18\x02 \x01(\x0c\"%\n\x12SendCommandRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"#\n\x13SendCommandResponse\x12\x0c\n\x04info\x18\x01 \x01(\t2\x9d\x01\n\nController\x12\x45\n\nSendStatus\x12\x19.eloope.SendStatusRequest\x1a\x1a.eloope.SendStatusResponse\"\x00\x12H\n\x0bSendCommand\x12\x1a.eloope.SendCommandRequest\x1a\x1b.eloope.SendCommandResponse\"\x00\x62\x06proto3')
)




_SENDSTATUSREQUEST = _descriptor.Descriptor(
  name='SendStatusRequest',
  full_name='eloope.SendStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks', full_name='eloope.SendStatusRequest.tasks', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completed_tasks', full_name='eloope.SendStatusRequest.completed_tasks', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='free_count', full_name='eloope.SendStatusRequest.free_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logs', full_name='eloope.SendStatusRequest.logs', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=118,
)


_SENDSTATUSRESPONSE = _descriptor.Descriptor(
  name='SendStatusResponse',
  full_name='eloope.SendStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='eloope.SendStatusResponse.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='eloope.SendStatusResponse.tasks', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=172,
)


_SENDCOMMANDREQUEST = _descriptor.Descriptor(
  name='SendCommandRequest',
  full_name='eloope.SendCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='eloope.SendCommandRequest.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=211,
)


_SENDCOMMANDRESPONSE = _descriptor.Descriptor(
  name='SendCommandResponse',
  full_name='eloope.SendCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='eloope.SendCommandResponse.info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=248,
)

DESCRIPTOR.message_types_by_name['SendStatusRequest'] = _SENDSTATUSREQUEST
DESCRIPTOR.message_types_by_name['SendStatusResponse'] = _SENDSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['SendCommandRequest'] = _SENDCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['SendCommandResponse'] = _SENDCOMMANDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendStatusRequest = _reflection.GeneratedProtocolMessageType('SendStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDSTATUSREQUEST,
  __module__ = 'service_pb2'
  # @@protoc_insertion_point(class_scope:eloope.SendStatusRequest)
  ))
_sym_db.RegisterMessage(SendStatusRequest)

SendStatusResponse = _reflection.GeneratedProtocolMessageType('SendStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDSTATUSRESPONSE,
  __module__ = 'service_pb2'
  # @@protoc_insertion_point(class_scope:eloope.SendStatusResponse)
  ))
_sym_db.RegisterMessage(SendStatusResponse)

SendCommandRequest = _reflection.GeneratedProtocolMessageType('SendCommandRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDCOMMANDREQUEST,
  __module__ = 'service_pb2'
  # @@protoc_insertion_point(class_scope:eloope.SendCommandRequest)
  ))
_sym_db.RegisterMessage(SendCommandRequest)

SendCommandResponse = _reflection.GeneratedProtocolMessageType('SendCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _SENDCOMMANDRESPONSE,
  __module__ = 'service_pb2'
  # @@protoc_insertion_point(class_scope:eloope.SendCommandResponse)
  ))
_sym_db.RegisterMessage(SendCommandResponse)



_CONTROLLER = _descriptor.ServiceDescriptor(
  name='Controller',
  full_name='eloope.Controller',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=251,
  serialized_end=408,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendStatus',
    full_name='eloope.Controller.SendStatus',
    index=0,
    containing_service=None,
    input_type=_SENDSTATUSREQUEST,
    output_type=_SENDSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommand',
    full_name='eloope.Controller.SendCommand',
    index=1,
    containing_service=None,
    input_type=_SENDCOMMANDREQUEST,
    output_type=_SENDCOMMANDRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTROLLER)

DESCRIPTOR.services_by_name['Controller'] = _CONTROLLER

# @@protoc_insertion_point(module_scope)
